@@ -31,17 +31,13 @@ from os import path
 from subprocess import Popen, TimeoutExpired
 
 from typedef.konstants import IBCTokens
+from typedef.konstants import HTTParams
 from typedef.win import CoinsList, WindowNames
 from conf.meile_config import MeileGuiConfig
 from cli.wallet import HandleWalletFunctions
 from cli.sentinel import NodeTreeData
 import main.main as Meile
-
-SERVER_ADDRESS      = "https://aimokoivunen.mathnodes.com:5000"
-APIURL              = "https://api.sentinel.mathnodes.com"
-API_PING_ENDPOINT   = "/api/ping"
-API_RATING_ENDPOINT = "/api/rating"
-TIMEOUT = 5
+from adapters import HTTPRequests
 
 class WalletInfoContent(BoxLayout):
     def __init__(self, seed_phrase, name, address, password, **kwargs):
@@ -86,8 +82,10 @@ class RatingContent(MDBoxLayout):
         UUID = Meile.app.root.get_screen(WindowNames.PRELOAD).UUID
         try:
             rating_dict = {'uuid' : "%s" % UUID, 'address' : "%s" % node_address, "rating" : rating}
-            ping = requests.post(SERVER_ADDRESS + API_RATING_ENDPOINT, json=rating_dict, timeout=TIMEOUT)
-            if ping.status_code == 200:
+            Request = HTTPRequests.MakeRequest()
+            http = Request.hadapter()
+            req = http.post(HTTParams.SERVER_URL + HTTParams.API_RATING_ENDPOINT, json=rating_dict)
+            if req.status_code == 200:
                 print("Rating Sent")
                 return 0
             else:
@@ -234,14 +232,15 @@ class RecycleViewRow(MDCard,RectangularElevationBehavior,ThemableBehavior, Hover
         
     def get_city_of_node(self, naddress):   
         
-
+        Request = HTTPRequests.MakeRequest()
+        http = Request.hadapter()
         endpoint = "/nodes/" + naddress.lstrip().rstrip()
         #print(APIURL + endpoint)
         try:
             requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
-            r = requests.get(APIURL + endpoint)
+            r = http.get(HTTParams.APIURL + endpoint)
             remote_url = r.json()['result']['node']['remote_url']
-            r = requests.get(remote_url + "/status", verify=False, timeout=TIMEOUT)
+            r = http.get(remote_url + "/status", verify=False)
             print(remote_url)
     
             NodeInfoJSON = r.json()
@@ -509,7 +508,9 @@ class RecycleViewSubRow(MDCard,RectangularElevationBehavior):
             UUID = Meile.app.root.get_screen(WindowNames.PRELOAD).UUID
             try:
                 uuid_dict = {'uuid' : "%s" % UUID, 'os' : "L"}
-                ping = requests.post(SERVER_ADDRESS + API_PING_ENDPOINT, json=uuid_dict, timeout=TIMEOUT)
+                Request = HTTPRequests.MakeRequest()
+                http = Request.hadapter()
+                ping = http.post(HTTParams.SERVER_URL + HTTParams.API_PING_ENDPOINT, json=uuid_dict)
                 if ping.status_code == 200:
                     print('ping')
                 else:
